@@ -299,7 +299,9 @@ class QuickbooksCore(SitesCore):
             self.browser.input_text(
                 '//input[@data-automation-id="input-rateField"]', str('%.2f' % (total_rate / 0.97 - total_rate))
             )
+            sleep(.5)
 
+        self.wait_element('//input[@data-automation-id="input-dropdown-terms-sales"]/..//div[contains(@class, "dropDownImage")]')
         self.browser.click_element_when_visible(
             '//input[@data-automation-id="input-dropdown-terms-sales"]/..//div[contains(@class, "dropDownImage")]'
         )
